@@ -1,9 +1,10 @@
 from typing import List
-from npstructures import RaggedArray
-from .delimited_buffers import DelimitedBuffer
-from .bnpdataclass import bnpdataclass
-from .strops import split, str_to_int
 import numpy as np
+from npstructures import RaggedArray
+from .bnpdataclass import bnpdataclass
+from .io.delimited_buffers import DelimitedBuffer
+from .io.strops import split, str_to_int
+
 
 @bnpdataclass
 class GfaPath:
@@ -25,7 +26,5 @@ class GfaPathBuffer(DelimitedBuffer):
         directions = np.where(all_node_texts[:, -1]=="+", 1, -1)
         node_ids = RaggedArray(node_ids, lengths)
         directions = RaggedArray(directions, lengths)
-        print(node_ids)
-        print(directions)
         data =  GfaPath(name, node_ids, directions)
         return data
