@@ -3,15 +3,16 @@ from itertools import chain
 import pytest
 import numpy as np
 from npstructures.testing import assert_npdataclass_equal 
-from bionumpy.sequences import from_sequence_array
-from bionumpy.file_buffers import FastQBuffer, TwoLineFastaBuffer
+from bionumpy.io.file_buffers import FastQBuffer, TwoLineFastaBuffer
 from bionumpy.datatypes import Interval, SNP, SequenceEntry, VCFEntry
-from bionumpy.delimited_buffers import BedBuffer, VCFBuffer, GfaSequenceBuffer, get_bufferclass_for_datatype
-from bionumpy.files import bnp_open
+from bionumpy.io.delimited_buffers import BedBuffer, VCFBuffer, GfaSequenceBuffer, get_bufferclass_for_datatype
+from bionumpy.io.files import bnp_open
 from .buffers import fastq_buffer, twoline_fasta_buffer, bed_buffer, vcf_buffer, vcf_buffer2, gfa_sequence_buffer, combos, data
-from bionumpy.parser import chunk_lines
+from bionumpy.io.parser import chunk_lines
 from bionumpy.bnpdataclass import bnpdataclass
+from bionumpy.encoded_array import from_encoded_array
 import bionumpy as bnp
+import glob
 
 np.seterr(all='raise')
 
@@ -33,7 +34,6 @@ def test_buffer_write(buffer_name):
     true_buf, data, buf_type = combos[buffer_name]
     if buffer_name == "multiline_fasta":
         buf_type.n_characters_per_line = 6
-    print(data)
     data = buf_type.dataclass.stack_with_ragged(data)
     buf = buf_type.from_data(data)
     print(buf.to_string())
@@ -60,7 +60,6 @@ def test_buffered_writer_ctx_manager(file, chunk_size):
 
 
 def test_custom_read():
-    from npstructures import npdataclass
 
     @bnpdataclass
     class SampleDC:
@@ -89,14 +88,14 @@ def test_raises_error_for_unsupported_types():
 
 def test_twoline_fasta_buffer(twoline_fasta_buffer):
     buf = TwoLineFastaBuffer.from_raw_buffer(twoline_fasta_buffer)
-    seqs = buf.get_sequences()
-    assert from_sequence_array(seqs) == ["CTTGTTGA", "CGG"]
+    seqs = buf.get_data()
+    assert from_encoded_array(seqs.sequence) == ["CTTGTTGA", "CGG"]
 
 
 def test_fastq_buffer(fastq_buffer):
     buf = FastQBuffer.from_raw_buffer(fastq_buffer)
-    seqs = buf.get_sequences()
-    assert from_sequence_array(seqs) == ["CTTGTTGA", "CGG"]
+    seqs = buf.get_data()
+    assert from_encoded_array(seqs.sequence) == ["CTTGTTGA", "CGG"]
 
 
 def test_gfa_sequence_buffer(gfa_sequence_buffer):
@@ -148,4 +147,22 @@ def test_read_chunk_after_read_chunks_returns_empty_dataclass():
 def test_read_gtf():
     file = bnp.open("example_data/small.gtf")
     chunk = file.read_chunk()
-    assert True
\ No newline at end of file
+    assert True
+
+
+@pytest.mark.parametrize("file_name", glob.glob("example_data/*"))
+def test_read_example_data(file_name):
+    if file_name.endswith(".sam"):
+        return
+
+    if file_name.endswith(".fa.fai"):
+        return
+
+    if file_name.endswith(".jaspar"):
+        return
+
+    file = bnp.open(file_name)
+    for chunk in file.read_chunks():
+        continue
+
+    assert True
